##
## Some R code for the Glyphosate experiment discussed
## in the lecture
##
##
## entering data
## (notice there are more convenient ways to enter data in R,
##  but for this small data the following is satisfactory)
##
x <- c(0,0,0.053,0.106,0.211,0.423,0.845,1.609,3.380)
yd <- c(107,110.9,106.2,97.3,105.9,88.5,74.4,46.2,30)
yt <- c(111,168.3,105.7,116.7,143.7,84.7,59.7,36.7,38)
##
## visualising the raw data
##
matplot(x, cbind(yd,yt), pch=19, col=c(4,2))
##
## transforming data to the log-log scale
##
lx <- log(1+x)
lyd <- log(yd)
lyt <- log(yt)
##
## visualising in the log-log scale
##
matplot(lx, cbind(lyd,lyt), pch=c(1,19), col=c(4,2))
##
## re-organising data as a data-frame
##
gly <- data.frame(y=c(lyd,lyt),x=lx,w=as.factor(rep(c(0,1), c(length(lyd), length(lyt)))))
##
## another way to produce the plot
## with different colors for each type of water (w)
##
with(gly,plot(y~x, col=c(4,2)[w], pch=19))
##
## Model 0:
## --------
## Fitting a regression model
## y = a + b x
##
reg0 <- lm(y~x, data=gly)
reg0
summary(reg0)
##
## and adding the fitted line to the plot
##
abline(coef(reg0))
##
## and another way to add the line:
##
xpred <- c(0,1.5)
ypred <- predict(reg0, new=data.frame(x=xpred))
lines(xpred,ypred, lwd=2)
## and this can be used to back-transform to the original scale of the data
xpred <- seq(0,1.5, len=101)
ypred <- predict(reg0, new=data.frame(x=xpred))
matplot(x, cbind(yd,yt), pch=19, col=c(4,2))
lines(exp(xpred)-1, exp(ypred))
##
## a plot of the ordered residuals 
##
plot(fitted(reg0), resid(reg0))
## and indicating residuals from each water type
plot(resid(reg0), col=c(4,2)[gly$w])
##
## and a plot of the residuals against fitted values
##
plot(fitted(reg0), resid(reg0))
## and indicating residuals from each water type
plot(fitted(reg0), resid(reg0), pch=19, col=c(4,2)[gly$w])
##
## Model 1:
## --------
## now fitting another regression model with
## different intercepts for the types of water
## y = a + a1 w + b x
reg1 <- lm(y~w+x, data=gly)
reg1
summary(reg1)
## plotting fitted model 
with(gly,plot(y~x, col=c(4,2)[w]))
abline(coef(reg1)[c(1,3)], col=4)
abline(sum(coef(reg1)[1:2]), coef(reg1)[3], col=2)
## and... doing it another (more elegant and general) way
with(gly,plot(y~x, col=c(4,2)[w]))
xpred <- c(0,1.5)
ypred.d <- predict(reg1, new=data.frame(x=xpred, w=as.factor(0)))
lines(xpred, ypred.d, col=4)
ypred.t <- predict(reg1, new=data.frame(x=xpred, w=as.factor(1)))
lines(xpred, ypred.t, col=2)
## residuals
plot(resid(reg1), pch=19, col=c(4,2)[gly$w])
plot(fitted(reg1), resid(reg1), pch=19, col=c(4,2)[gly$w])
##
## Model 2:
## --------
## now fitting yet another regression model with
## different intercepts and slopes for the types of water
## y = a + a1 w + b x + b1 w x
##
reg2 <- lm(y~w*x, data=gly)
reg2
summary(reg2)
coef(reg2)
with(gly,plot(y~x, col=c(4,2)[w]))
abline(coef(reg2)[c(1,3)], col=4)
abline(sum(coef(reg2)[1:2]), sum(coef(reg2)[3:4]), col=2)
## and... doing it another (more elegant and general) way
with(gly,plot(y~x, col=c(4,2)[w]))
xpred <- c(0,1.5)
ypred.d <- predict(reg2, new=data.frame(x=xpred, w=as.factor(0)))
lines(xpred, ypred.d, col=4)
ypred.t <- predict(reg2, new=data.frame(x=xpred, w=as.factor(1)))
lines(xpred, ypred.t, col=2)
## residuals
plot(resid(reg2), pch=19, col=c(4,2)[gly$w])
plot(fitted(reg2), resid(reg2), pch=19, col=c(4,2)[gly$w])
## residuals
plot(resid(reg2), pch=19, col=c(4,2)[gly$w])
plot(fitted(reg2), resid(reg1), pch=19, col=c(4,2)[gly$w])

##
## Notice the reduction in variance
##
var(resid(reg0))
var(resid(reg1))
var(resid(reg2))
##
## ... on the other hand you are increasing the number of parameters
## (2 for Model_0, 3 for Model_1 and 4 for Model_2)
## and increasing the complexity of the model.
## Which one would you choose?
##
